@@ -131,7 +131,7 @@ def db_session(pg_config: dict = None, mysql_config: dict = None, timeout: int =
                         raise Exception("unsupported return type for @db_session: {0}".format(type(ret)))
 
                     try:
-                        if code in [0, 200, 903, 909, 904]:
+                        if code in [0, 200, 903, 909]:
                             logger.info("DB_SESSION commit due to zero code")
                             if sess.pg_sess is not None:
                                 logger.debug("DB_SESSION PG_SESS[{}]".format(sess.pg_sess))
